ProductMetricError

Enum ProductMetricError 

pub enum ProductMetricError {
    NotInitialized,
    DuplicateRegistration {
        subsystem: &'static str,
        name: &'static str,
    },
    UnknownMetric {
        subsystem: &'static str,
        name: &'static str,
    },
    WrongKind {
        subsystem: &'static str,
        name: &'static str,
        actual: MetricKind,
        expected: MetricKind,
    },
    LabelCountMismatch {
        subsystem: &'static str,
        name: &'static str,
        expected: usize,
        actual: usize,
    },
    Prometheus(String),
    LockPoisoned,
}
Errors returned by product metric registration or recording.

Variants



NotInitialized

The Prometheus registry has not been initialized.



DuplicateRegistration

A product metric with the same subsystem/name was already registered.

Fields

subsystem: &'static str

Owning subsystem.

name: &'static str

Metric name.



UnknownMetric

The handle does not point to a registered metric.

Fields

subsystem: &'static str

Owning subsystem.

name: &'static str

Metric name.



WrongKind

The recording operation does not match the registered metric kind.

Fields

subsystem: &'static str

Owning subsystem.

name: &'static str

Metric name.

actual: MetricKind

Registered kind.

expected: MetricKind

Expected kind.



LabelCountMismatch

The number of label values did not match the descriptor.

Fields

subsystem: &'static str

Owning subsystem.

name: &'static str

Metric name.

expected: usize

Expected label value count.

actual: usize

Actual label value count.



Prometheus(String)

Prometheus rejected the metric collector.



LockPoisoned

The product metric registry lock was poisoned.