pub fn register_product_gauge(
descriptor: MetricDescriptor,
) -> ProductMetricResult<ProductGauge>Expand description
Registers a product gauge and returns a typed handle.
Errors
Returns an error when the gauge descriptor cannot be registered.