register_product_histogram

Function register_product_histogram 

pub fn register_product_histogram(
    descriptor: MetricDescriptor,
) -> ProductMetricResult<ProductHistogram>
Registers a product histogram and returns a typed handle.

Errors

Returns an error when the histogram descriptor cannot be registered.