register_product_metrics

Function register_product_metrics 

pub fn register_product_metrics<I>(
    descriptors: I,
) -> ProductMetricResult<Vec<ProductMetricHandle>>
where I: IntoIterator<Item = MetricDescriptor>,
Registers multiple product-owned metric families in order.

The batch is all-or-nothing: when any descriptor fails, the families this batch already registered are rolled back so fixing the failure and retrying does not trip over DuplicateRegistration.

Errors

Returns an error when validation or registration of any descriptor in the batch fails.