pub struct ProductGauge { /* private fields */ }Expand description
Typed handle for a registered product gauge.
Implementations
Sourceimpl ProductGauge
impl ProductGauge
Sourcepub fn from_handle(handle: ProductMetricHandle) -> ProductMetricResult<Self>
pub fn from_handle(handle: ProductMetricHandle) -> ProductMetricResult<Self>
Creates a typed gauge from an opaque product metric handle.
Errors
Returns an error when the handle is not a gauge or its descriptor is unavailable.
Sourcepub const fn handle(&self) -> ProductMetricHandle
pub const fn handle(&self) -> ProductMetricHandle
Returns the underlying opaque handle.
Sourcepub fn set(&self, label_values: &[&str], value: f64)
pub fn set(&self, label_values: &[&str], value: f64)
Sets this gauge and logs recording failures.
Sourcepub fn try_set(
&self,
label_values: &[&str],
value: f64,
) -> ProductMetricResult<()>
pub fn try_set( &self, label_values: &[&str], value: f64, ) -> ProductMetricResult<()>
Sets this gauge and returns recording failures.
Errors
Returns an error when the label count is wrong or the gauge cannot be set.