pub fn register_product_counter(
descriptor: MetricDescriptor,
) -> ProductMetricResult<ProductCounter>Expand description
Registers a product counter and returns a typed handle.
Errors
Returns an error when the counter descriptor cannot be registered.