pub fn register_product_histogram(
descriptor: MetricDescriptor,
) -> ProductMetricResult<ProductHistogram>Expand description
Registers a product histogram and returns a typed handle.
Errors
Returns an error when the histogram descriptor cannot be registered.