pub struct ProductHistogram { /* private fields */ }Expand description
Typed handle for a registered product histogram.
Implementations
Sourceimpl ProductHistogram
impl ProductHistogram
Sourcepub fn from_handle(handle: ProductMetricHandle) -> ProductMetricResult<Self>
pub fn from_handle(handle: ProductMetricHandle) -> ProductMetricResult<Self>
Creates a typed histogram from an opaque product metric handle.
Sourcepub const fn handle(&self) -> ProductMetricHandle
pub const fn handle(&self) -> ProductMetricHandle
Returns the underlying opaque handle.
Sourcepub fn observe(&self, label_values: &[&str], value: f64)
pub fn observe(&self, label_values: &[&str], value: f64)
Observes a value in this histogram and logs recording failures.
Sourcepub fn try_observe(
&self,
label_values: &[&str],
value: f64,
) -> ProductMetricResult<()>
pub fn try_observe( &self, label_values: &[&str], value: f64, ) -> ProductMetricResult<()>
Observes a value in this histogram and returns recording failures.